@@ -31,8 +31,9 @@ struct _CallbackData
 
 static const char
 instructions[] =
-  "Press and drag any of the three mouse buttons to add a clip with different "
-  "shapes. Press 'r' to reset or 'u' to undo the last clip.";
+  "Left button and drag to draw a rectangle, control+left to draw a rotated "
+  "rectangle or shift+left to draw a path. Press 'r' to reset or 'u' "
+  "to undo the last clip.";
 
 static void
 path_shapes (gint x, gint y, gint width, gint height)
@@ -231,10 +232,29 @@ on_button_press (ClutterActor *stage, ClutterButtonEvent *event,
   data->current_clip.x1 = data->current_clip.x2 = event->x;
   data->current_clip.y1 = data->current_clip.y2 = event->y;
 
-  data->current_clip.type
-    = event->button == 1 ? CLIP_RECTANGLE
-    : event->button == 2 ? CLIP_SHAPES
-    : CLIP_ROTATED_RECTANGLE;
+  switch (event->button)
+    {
+    case CLUTTER_BUTTON_PRIMARY:
+      if (clutter_event_has_shift_modifier ((ClutterEvent *) event))
+        data->current_clip.type = CLIP_SHAPES;
+      else if (clutter_event_has_control_modifier ((ClutterEvent *) event))
+        data->current_clip.type = CLIP_ROTATED_RECTANGLE;
+      else
+        data->current_clip.type = CLIP_RECTANGLE;
+      break;
+
+    case CLUTTER_BUTTON_SECONDARY:
+      data->current_clip.type = CLIP_ROTATED_RECTANGLE;
+      break;
+
+    case CLUTTER_BUTTON_MIDDLE:
+      data->current_clip.type = CLIP_SHAPES;
+      break;
+
+    default:
+      data->current_clip.type = CLIP_NONE;
+      break;
+    }
 
   clutter_actor_queue_redraw (stage);
 
@@ -325,7 +345,9 @@ test_clip_main (int argc, char **argv)
   data.current_clip.type = CLIP_NONE;
   data.clips = NULL;
 
-  data.stage = clutter_stage_get_default ();
+  data.stage = clutter_stage_new ();
+  clutter_stage_set_title (CLUTTER_STAGE (data.stage), "Clipping");
+  g_signal_connect (data.stage, "destroy", G_CALLBACK (clutter_main_quit), NULL);
 
   stub_actor = clutter_rectangle_new ();
   clutter_container_add (CLUTTER_CONTAINER (data.stage), stub_actor, NULL);
@@ -366,3 +388,9 @@ test_clip_main (int argc, char **argv)
 
   return 0;
 }
+
+G_MODULE_EXPORT const char *
+test_clip_describe (void)
+{
+  return "Actor clipping with various techniques";
+}
